@@ -13,24 +13,23 @@
 #  limitations under the License.
 
 utf8_encode <- function(x, width = 0L, quote = FALSE, justify = "left",
-                        escapes = NULL, display = FALSE, utf8 = NULL)
-{
-    if (is.null(x)) {
-        return(NULL)
-    }
+                        escapes = NULL, display = FALSE, utf8 = NULL) {
+  if (is.null(x)) {
+    return(NULL)
+  }
 
-    if (!is.character(x)) {
-        stop("argument is not a character object")
-    }
+  if (!is.character(x)) {
+    stop("argument is not a character object")
+  }
 
-    with_rethrow({
-        width <- as_integer_scalar("width", width)
-        quote <- as_option("quote", quote)
-        justify <- as_justify("justify", justify)
-        escapes <- as_style("escapes", escapes)
-        display <- as_option("display", display)
-        utf8 <- as_output_utf8("utf8", utf8)
-    })
+  with_rethrow({
+    width <- as_integer_scalar("width", width)
+    quote <- as_option("quote", quote)
+    justify <- as_justify("justify", justify)
+    escapes <- as_style("escapes", escapes)
+    display <- as_option("display", display)
+    utf8 <- as_output_utf8("utf8", utf8)
+  })
 
-    .Call(rutf8_utf8_encode, x, width, quote, justify, escapes, display, utf8)
+  .Call(rutf8_utf8_encode, x, width, quote, justify, escapes, display, utf8)
 }
